==> nextcloud-25.0.11.tgz: nextcloud/apps/comments/l10n/fa.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "نظرات",
    "You commented" : "You commented",
    "{author} commented" : "{author} commented",
    "You commented on %1$s" : "You commented on %1$s",
    "You commented on {file}" : "You commented on {file}",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "{author} commented on {file}" : "{author} commented on {file}",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "You were mentioned on \"{file}\", in a comment by a user that has since been deleted",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mentioned you in a comment on \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin to add comments to files",
    "Edit comment" : "ویرایش توضیح",
    "Delete comment" : "حذف توضیح",
    "Cancel edit" : "Cancel edit",
    "Post comment" : "Post comment",
    "No comments yet, start the conversation!" : "هنوز هیچ نظری ندارید ، مکالمه را شروع کنید!",
    "No more messages" : "No more messages",
    "Retry" : "تلاش دوباره",
    "Failed to mark comments as read" : "Failed to mark comments as read",
    "Unable to load the comments list" : "Unable to load the comments list",
    "_%n unread comment_::_%n unread comments_" : ["%n unread comment","%n unread comments"],
    "_1 new comment_::_{unread} new comments_" : ["1 new comment","{unread} new comments"],
    "Comment" : "نظر",
    "An error occurred while trying to edit the comment" : "An error occurred while trying to edit the comment",
    "Comment deleted" : "توضیح حذف",
    "An error occurred while trying to delete the comment" : "An error occurred while trying to delete the comment",
    "An error occurred while trying to create the comment" : "An error occurred while trying to create the comment",
    "%1$s commented" : "%1$s commented"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/comments/l10n/fa.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "نظرات",
    "You commented" : "You commented",
    "{author} commented" : "{author} commented",
    "You commented on %1$s" : "You commented on %1$s",
    "You commented on {file}" : "You commented on {file}",
    "%1$s commented on %2$s" : "%1$s commented on %2$s",
    "{author} commented on {file}" : "{author} commented on {file}",
    "<strong>Comments</strong> for files" : "<strong>Comments</strong> for files",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "You were mentioned on \"{file}\", in a comment by a user that has since been deleted",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} mentioned you in a comment on \"{file}\"",
    "Files app plugin to add comments to files" : "Files app plugin to add comments to files",
    "Edit comment" : "ویرایش توضیح",
    "Delete comment" : "حذف توضیح",
    "Cancel edit" : "Cancel edit",
    "Post comment" : "Post comment",
    "No comments yet, start the conversation!" : "هنوز هیچ نظری ندارید ، مکالمه را شروع کنید!",
    "No more messages" : "No more messages",
    "Retry" : "تلاش دوباره",
    "Failed to mark comments as read" : "Failed to mark comments as read",
    "Unable to load the comments list" : "Unable to load the comments list",
    "_1 new comment_::_{unread} new comments_" : ["1 new comment","{unread} new comments"],
    "Comment" : "نظر",
    "An error occurred while trying to edit the comment" : "An error occurred while trying to edit the comment",
    "Comment deleted" : "توضیح حذف",
    "An error occurred while trying to delete the comment" : "An error occurred while trying to delete the comment",
    "An error occurred while trying to create the comment" : "An error occurred while trying to create the comment",
    "%1$s commented" : "%1$s commented",
    "_%n unread comment_::_%n unread comments_" : ["%n unread comment","%n unread comments"]
},
"nplurals=2; plural=(n > 1);");
